import React from 'react';
import PropTypes from 'prop-types';

import Checkbox from '@material-ui/core/Checkbox';
import FormControl from '@material-ui/core/FormControl';
import FormControlLabel from '@material-ui/core/FormControlLabel';
import FormHelperText from '@material-ui/core/FormHelperText';
import FormLabel from '@material-ui/core/FormLabel';
import FormGroup from '@material-ui/core/FormGroup';
import { withStyles } from '@material-ui/core/styles';

import { fieldShape, formShape, optionShape } from '../utils/PropTypes';

class CheckboxGroupField extends React.Component {
  state = {
    dirty: false,
  };

  handleChange = event => {
    const { field } = this.props;
    let value;
    field.onChange({
      target: { value, name: field.name },
    });
    if (this.props.onChange) {
      this.props.onChange(value);
    }
    if (!this.state.dirty) {
      this.setState({
        dirty: true,
      });
    }
  };

  render() {
    const {
      field: { onChange: fieldOnChange, onBlur, ...field },
      form: { errors },
      options,
      label,
      helperText,
      FormLabelProps,
      FormHelperTextProps,
      FormControlLabelProps,
      CheckboxProps,
      FormGroupProps,
      onChange,
      className,
      classes,
      ...props
    } = this.props;
    const message = this.state.dirty && errors[field.name];
    return (
      <FormControl
        error={Boolean(message)}
        {...props}
      >
        {label && (
          <FormLabel
            {...FormLabelProps}
          >
            {label}
          </FormLabel>
        )}
        <FormGroup {...FormGroupProps}>
          <FormControlLabel
            control={
              <Checkbox
                {...CheckboxProps}
                value={option.value}
                onChange={this.handleChange}
                checked={option.value === field.value}
              />
            }
            {...FormControlLabelProps}
          />
        </FormGroup>
        {(message || helperText) && (
          <FormHelperText
            {...FormHelperTextProps}
          >
            {message || helperText}
          </FormHelperText>
        )}
      </FormControl>
    );
  }
}

if (process.env.NODE_ENV !== 'production') {
  CheckboxGroupField.propTypes = {
    field: fieldShape.isRequired,
    form: formShape.isRequired,
    options: PropTypes.arrayOf(optionShape).isRequired,
    label: PropTypes.node,
    helperText: PropTypes.node,
    CheckboxProps: PropTypes.object,
    FormGroupProps: PropTypes.object,
    FormLabelProps: PropTypes.object,
    FormHelperTextProps: PropTypes.object,
    FormControlLabelProps: PropTypes.object,
    className: PropTypes.string,
    classes: PropTypes.object.isRequired,
  };
}

export default withStyles(s)(CheckboxGroupField);
